@@ -56,7 +56,7 @@ class RabbitMQService:
     # 连接状态监控任务
     _connection_monitor_task: Optional[asyncio.Task] = None
     # 重连配置
-    RECONNECT_INTERVAL = 3  # 重连基础间隔（秒）
+    RECONNECT_INTERVAL = 15  # 重连基础间隔（秒）
     MAX_RECONNECT_ATTEMPTS = 10  # 最大连续重连次数
 
     @classmethod
@@ -118,10 +118,6 @@ class RabbitMQService:
                 username=cls._config.get('username', ""),
                 password=cls._config.get('password', ""),
                 virtualhost=cls._config.get('virtual-host', "/"),
-                connection_pool_size=cls._config.get(
-                    'connection_pool_size', 5),
-                channel_pool_size=cls._config.get('channel_pool_size', 10),
-                heartbeat=cls._config.get('heartbeat', 30),
                 app_name=cls._config.get("APP_NAME", "")
             )
 
@@ -142,8 +138,7 @@ class RabbitMQService:
         logger.info("RabbitMQ连接监控任务启动")
         while not cls._is_shutdown:
             try:
-                # 每5秒检查一次连接状态
-                await asyncio.sleep(5)
+                await asyncio.sleep(cls.RECONNECT_INTERVAL)  # 固定15秒间隔
 
                 # 跳过未初始化的连接池
                 if not cls._connection_pool or not cls._connection_pool._initialized:
@@ -213,6 +208,10 @@ class RabbitMQService:
     @classmethod
     async def _reconnect_client(cls, client_name: str, client: RabbitMQClient) -> bool:
         """客户端重连（带重试机制）"""
+        # 重连冷却，避免任务堆积
+        cooldown = cls.RECONNECT_INTERVAL * 2
+        await asyncio.sleep(cooldown)
+
         for attempt in range(cls.MAX_RECONNECT_ATTEMPTS):
             try:
                 # 执行重连
@@ -237,20 +236,14 @@ class RabbitMQService:
                 else:
                     logger.warning(
                         f"客户端 '{client_name}' 重连尝试 {attempt+1} 失败：资源未完全初始化")
-
-            except aio_pika_exceptions.AMQPConnectionError as e:
-                logger.error(
-                    f"客户端 '{client_name}' 重连尝试 {attempt+1} 失败（连接错误）: {str(e)}")
-            except aio_pika_exceptions.AMQPChannelError as e:
-                logger.error(
-                    f"客户端 '{client_name}' 重连尝试 {attempt+1} 失败（通道错误）: {str(e)}")
             except Exception as e:
                 logger.error(
                     f"客户端 '{client_name}' 重连尝试 {attempt+1} 失败: {str(e)}", exc_info=True)
 
-            # 重试间隔（指数退避）
-            await asyncio.sleep(cls.RECONNECT_INTERVAL * (2 ** attempt))
+            await asyncio.sleep(cls.RECONNECT_INTERVAL)
 
+        if not cls._is_shutdown:
+            asyncio.create_task(cls._reconnect_client(client_name, client))
         return False
 
     @classmethod
@@ -587,9 +580,19 @@ class RabbitMQService:
             logger.warning("服务已关闭，无法启动消费者")
             return
 
-        if client_name in cls._consumer_tasks and not cls._consumer_tasks[client_name].done():
-            logger.info(f"消费者 '{client_name}' 已在运行中，无需重复启动")
-            return
+        # 检查任务状态，避免重复创建
+        if client_name in cls._consumer_tasks:
+            existing_task = cls._consumer_tasks[client_name]
+            if not existing_task.done():
+                # 检查任务是否处于异常状态，仅在异常时重启
+                if existing_task.exception() is not None:
+                    logger.info(f"消费者 '{client_name}' 任务异常，重启")
+                    existing_task.cancel()
+                else:
+                    logger.info(f"消费者 '{client_name}' 已在运行中，无需重复启动")
+                    return
+            else:
+                logger.info(f"消费者 '{client_name}' 任务已完成，重新启动")
 
         if client_name not in cls._clients:
             raise ValueError(f"RabbitMQ客户端 '{client_name}' 未初始化")
@@ -804,8 +807,7 @@ class RabbitMQService:
                     retry_count += 1
                     logger.warning(
                         f"发送器 '{queue_name}' 第 {retry_count} 次重连失败: {str(e)}")
-                    if retry_count < max_retry:
-                        await asyncio.sleep(1)
+                    await asyncio.sleep(cls.RECONNECT_INTERVAL)
 
             if retry_count >= max_retry and not await sender.is_connected:
                 error_msg = f"发送器 '{queue_name}' 经过 {max_retry} 次重连仍失败"
@@ -889,8 +891,6 @@ class RabbitMQService:
                     task.cancel()
                     try:
                         await asyncio.wait_for(task, timeout=timeout)
-                    except asyncio.TimeoutError:
-                        logger.warning(f"消费者 '{client_name}' 关闭超时")
                     except Exception as e:
                         logger.error(f"关闭消费者 '{client_name}' 失败: {str(e)}")
 
